# coding: utf-8

"""
    MN Frontoffice CORE & PERE

    Highly available and searchable datastore for MN  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from frontoffice.configuration import Configuration


class Partnerschap(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'partner': 'PersoonsGegevensBasic',
        'soort': 'str',
        'begindatum': 'DatumDelen',
        'einddatum': 'DatumDelen'
    }

    attribute_map = {
        'partner': 'Partner',
        'soort': 'soort',
        'begindatum': 'Begindatum',
        'einddatum': 'Einddatum'
    }

    def __init__(self, partner=None, soort=None, begindatum=None, einddatum=None, local_vars_configuration=None):  # noqa: E501
        """Partnerschap - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._partner = None
        self._soort = None
        self._begindatum = None
        self._einddatum = None
        self.discriminator = None

        self.partner = partner
        self.soort = soort
        self.begindatum = begindatum
        if einddatum is not None:
            self.einddatum = einddatum

    @property
    def partner(self):
        """Gets the partner of this Partnerschap.  # noqa: E501


        :return: The partner of this Partnerschap.  # noqa: E501
        :rtype: PersoonsGegevensBasic
        """
        return self._partner

    @partner.setter
    def partner(self, partner):
        """Sets the partner of this Partnerschap.


        :param partner: The partner of this Partnerschap.  # noqa: E501
        :type: PersoonsGegevensBasic
        """
        if self.local_vars_configuration.client_side_validation and partner is None:  # noqa: E501
            raise ValueError("Invalid value for `partner`, must not be `None`")  # noqa: E501

        self._partner = partner

    @property
    def soort(self):
        """Gets the soort of this Partnerschap.  # noqa: E501


        :return: The soort of this Partnerschap.  # noqa: E501
        :rtype: str
        """
        return self._soort

    @soort.setter
    def soort(self, soort):
        """Sets the soort of this Partnerschap.


        :param soort: The soort of this Partnerschap.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and soort is None:  # noqa: E501
            raise ValueError("Invalid value for `soort`, must not be `None`")  # noqa: E501

        self._soort = soort

    @property
    def begindatum(self):
        """Gets the begindatum of this Partnerschap.  # noqa: E501


        :return: The begindatum of this Partnerschap.  # noqa: E501
        :rtype: DatumDelen
        """
        return self._begindatum

    @begindatum.setter
    def begindatum(self, begindatum):
        """Sets the begindatum of this Partnerschap.


        :param begindatum: The begindatum of this Partnerschap.  # noqa: E501
        :type: DatumDelen
        """
        if self.local_vars_configuration.client_side_validation and begindatum is None:  # noqa: E501
            raise ValueError("Invalid value for `begindatum`, must not be `None`")  # noqa: E501

        self._begindatum = begindatum

    @property
    def einddatum(self):
        """Gets the einddatum of this Partnerschap.  # noqa: E501


        :return: The einddatum of this Partnerschap.  # noqa: E501
        :rtype: DatumDelen
        """
        return self._einddatum

    @einddatum.setter
    def einddatum(self, einddatum):
        """Sets the einddatum of this Partnerschap.


        :param einddatum: The einddatum of this Partnerschap.  # noqa: E501
        :type: DatumDelen
        """

        self._einddatum = einddatum

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Partnerschap):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Partnerschap):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MN Frontoffice CORE & PERE

    Highly available and searchable datastore for MN  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from frontoffice.configuration import Configuration


class Contact(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'uuid': 'str',
        'version': 'int',
        'identificatie': 'str',
        'administratie': 'str',
        'relatiesoort': 'str',
        'persoonsnummer': 'str',
        'persoonsgegevens': 'PersoonsGegevens',
        'contactgegevens_events': 'list[ContactgegevensEvent]',
        'contactgegevens': 'AnyOfobjectobjectobject'
    }

    attribute_map = {
        'uuid': 'uuid',
        'version': 'version',
        'identificatie': 'identificatie',
        'administratie': 'administratie',
        'relatiesoort': 'relatiesoort',
        'persoonsnummer': 'persoonsnummer',
        'persoonsgegevens': 'persoonsgegevens',
        'contactgegevens_events': 'contactgegevens_events',
        'contactgegevens': 'contactgegevens'
    }

    def __init__(self, uuid='45fd9033-4b8c-4f12-9a9c-be7bb36162b4', version=0, identificatie=None, administratie=None, relatiesoort=None, persoonsnummer=None, persoonsgegevens=None, contactgegevens_events=[], contactgegevens=None, local_vars_configuration=None):  # noqa: E501
        """Contact - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._uuid = None
        self._version = None
        self._identificatie = None
        self._administratie = None
        self._relatiesoort = None
        self._persoonsnummer = None
        self._persoonsgegevens = None
        self._contactgegevens_events = None
        self._contactgegevens = None
        self.discriminator = None

        if uuid is not None:
            self.uuid = uuid
        if version is not None:
            self.version = version
        self.identificatie = identificatie
        if administratie is not None:
            self.administratie = administratie
        if relatiesoort is not None:
            self.relatiesoort = relatiesoort
        if persoonsnummer is not None:
            self.persoonsnummer = persoonsnummer
        if persoonsgegevens is not None:
            self.persoonsgegevens = persoonsgegevens
        if contactgegevens_events is not None:
            self.contactgegevens_events = contactgegevens_events
        if contactgegevens is not None:
            self.contactgegevens = contactgegevens

    @property
    def uuid(self):
        """Gets the uuid of this Contact.  # noqa: E501


        :return: The uuid of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this Contact.


        :param uuid: The uuid of this Contact.  # noqa: E501
        :type: str
        """

        self._uuid = uuid

    @property
    def version(self):
        """Gets the version of this Contact.  # noqa: E501


        :return: The version of this Contact.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Contact.


        :param version: The version of this Contact.  # noqa: E501
        :type: int
        """

        self._version = version

    @property
    def identificatie(self):
        """Gets the identificatie of this Contact.  # noqa: E501


        :return: The identificatie of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._identificatie

    @identificatie.setter
    def identificatie(self, identificatie):
        """Sets the identificatie of this Contact.


        :param identificatie: The identificatie of this Contact.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and identificatie is None:  # noqa: E501
            raise ValueError("Invalid value for `identificatie`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                identificatie is not None and not re.search(r'^([A-Z\s-]+\|\w+\|\w+)$', identificatie)):  # noqa: E501
            raise ValueError(r"Invalid value for `identificatie`, must be a follow pattern or equal to `/^([A-Z\s-]+\|\w+\|\w+)$/`")  # noqa: E501

        self._identificatie = identificatie

    @property
    def administratie(self):
        """Gets the administratie of this Contact.  # noqa: E501


        :return: The administratie of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._administratie

    @administratie.setter
    def administratie(self, administratie):
        """Sets the administratie of this Contact.


        :param administratie: The administratie of this Contact.  # noqa: E501
        :type: str
        """

        self._administratie = administratie

    @property
    def relatiesoort(self):
        """Gets the relatiesoort of this Contact.  # noqa: E501


        :return: The relatiesoort of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._relatiesoort

    @relatiesoort.setter
    def relatiesoort(self, relatiesoort):
        """Sets the relatiesoort of this Contact.


        :param relatiesoort: The relatiesoort of this Contact.  # noqa: E501
        :type: str
        """

        self._relatiesoort = relatiesoort

    @property
    def persoonsnummer(self):
        """Gets the persoonsnummer of this Contact.  # noqa: E501


        :return: The persoonsnummer of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._persoonsnummer

    @persoonsnummer.setter
    def persoonsnummer(self, persoonsnummer):
        """Sets the persoonsnummer of this Contact.


        :param persoonsnummer: The persoonsnummer of this Contact.  # noqa: E501
        :type: str
        """

        self._persoonsnummer = persoonsnummer

    @property
    def persoonsgegevens(self):
        """Gets the persoonsgegevens of this Contact.  # noqa: E501

        Persoonsgegevens for a Contact  # noqa: E501

        :return: The persoonsgegevens of this Contact.  # noqa: E501
        :rtype: PersoonsGegevens
        """
        return self._persoonsgegevens

    @persoonsgegevens.setter
    def persoonsgegevens(self, persoonsgegevens):
        """Sets the persoonsgegevens of this Contact.

        Persoonsgegevens for a Contact  # noqa: E501

        :param persoonsgegevens: The persoonsgegevens of this Contact.  # noqa: E501
        :type: PersoonsGegevens
        """

        self._persoonsgegevens = persoonsgegevens

    @property
    def contactgegevens_events(self):
        """Gets the contactgegevens_events of this Contact.  # noqa: E501

        A list of events for a Contact  # noqa: E501

        :return: The contactgegevens_events of this Contact.  # noqa: E501
        :rtype: list[ContactgegevensEvent]
        """
        return self._contactgegevens_events

    @contactgegevens_events.setter
    def contactgegevens_events(self, contactgegevens_events):
        """Sets the contactgegevens_events of this Contact.

        A list of events for a Contact  # noqa: E501

        :param contactgegevens_events: The contactgegevens_events of this Contact.  # noqa: E501
        :type: list[ContactgegevensEvent]
        """

        self._contactgegevens_events = contactgegevens_events

    @property
    def contactgegevens(self):
        """Gets the contactgegevens of this Contact.  # noqa: E501

        The current snapshort of a Contact  # noqa: E501

        :return: The contactgegevens of this Contact.  # noqa: E501
        :rtype: AnyOfobjectobjectobject
        """
        return self._contactgegevens

    @contactgegevens.setter
    def contactgegevens(self, contactgegevens):
        """Sets the contactgegevens of this Contact.

        The current snapshort of a Contact  # noqa: E501

        :param contactgegevens: The contactgegevens of this Contact.  # noqa: E501
        :type: AnyOfobjectobjectobject
        """

        self._contactgegevens = contactgegevens

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Contact):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Contact):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MN Frontoffice CORE & PERE

    Highly available and searchable datastore for MN  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from frontoffice.api_client import ApiClient
from frontoffice.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class ContactgegevensApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_events_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_events_get(self, administratie, relatiesoort, persoonsnummer, **kwargs):  # noqa: E501
        """Get Events  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_events_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_events_get(administratie, relatiesoort, persoonsnummer, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str administratie: (required)
        :param str relatiesoort: (required)
        :param str persoonsnummer: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[ContactgegevensEvent]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_events_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_events_get_with_http_info(administratie, relatiesoort, persoonsnummer, **kwargs)  # noqa: E501

    def get_events_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_events_get_with_http_info(self, administratie, relatiesoort, persoonsnummer, **kwargs):  # noqa: E501
        """Get Events  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_events_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_events_get_with_http_info(administratie, relatiesoort, persoonsnummer, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str administratie: (required)
        :param str relatiesoort: (required)
        :param str persoonsnummer: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[ContactgegevensEvent], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'administratie',
            'relatiesoort',
            'persoonsnummer'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_events_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_events_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'administratie' is set
        if self.api_client.client_side_validation and ('administratie' not in local_var_params or  # noqa: E501
                                                        local_var_params['administratie'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `administratie` when calling `get_events_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_events_get`")  # noqa: E501
        # verify the required parameter 'relatiesoort' is set
        if self.api_client.client_side_validation and ('relatiesoort' not in local_var_params or  # noqa: E501
                                                        local_var_params['relatiesoort'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `relatiesoort` when calling `get_events_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_events_get`")  # noqa: E501
        # verify the required parameter 'persoonsnummer' is set
        if self.api_client.client_side_validation and ('persoonsnummer' not in local_var_params or  # noqa: E501
                                                        local_var_params['persoonsnummer'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `persoonsnummer` when calling `get_events_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_events_get`")  # noqa: E501

        if self.api_client.client_side_validation and 'persoonsnummer' in local_var_params and not re.search(r'^(?:CON-)?(\d+)$', local_var_params['persoonsnummer']):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `persoonsnummer` when calling `get_events_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_events_get`, must conform to the pattern `/^(?:CON-)?(\d+)$/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'administratie' in local_var_params:
            path_params['administratie'] = local_var_params['administratie']  # noqa: E501
        if 'relatiesoort' in local_var_params:
            path_params['relatiesoort'] = local_var_params['relatiesoort']  # noqa: E501
        if 'persoonsnummer' in local_var_params:
            path_params['persoonsnummer'] = local_var_params['persoonsnummer']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['HTTPBasic']  # noqa: E501

        return self.api_client.call_api(
            '/v2/contactgegevens/{administratie}/{relatiesoort}/{persoonsnummer}/events', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ContactgegevensEvent]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_search_core_v2_search_core_administratie_get(self, administratie, **kwargs):  # noqa: E501
        """Get Search Core  # noqa: E501

        Search for Contactgegevens only  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_search_core_v2_search_core_administratie_get(administratie, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str administratie: (required)
        :param str email:
        :param str telefoonnummer:
        :param str werkgevernummer:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Contact]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_search_core_v2_search_core_administratie_get_with_http_info(administratie, **kwargs)  # noqa: E501

    def get_search_core_v2_search_core_administratie_get_with_http_info(self, administratie, **kwargs):  # noqa: E501
        """Get Search Core  # noqa: E501

        Search for Contactgegevens only  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_search_core_v2_search_core_administratie_get_with_http_info(administratie, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str administratie: (required)
        :param str email:
        :param str telefoonnummer:
        :param str werkgevernummer:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Contact], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'administratie',
            'email',
            'telefoonnummer',
            'werkgevernummer'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_search_core_v2_search_core_administratie_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'administratie' is set
        if self.api_client.client_side_validation and ('administratie' not in local_var_params or  # noqa: E501
                                                        local_var_params['administratie'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `administratie` when calling `get_search_core_v2_search_core_administratie_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'administratie' in local_var_params:
            path_params['administratie'] = local_var_params['administratie']  # noqa: E501

        query_params = []
        if 'email' in local_var_params and local_var_params['email'] is not None:  # noqa: E501
            query_params.append(('email', local_var_params['email']))  # noqa: E501
        if 'telefoonnummer' in local_var_params and local_var_params['telefoonnummer'] is not None:  # noqa: E501
            query_params.append(('telefoonnummer', local_var_params['telefoonnummer']))  # noqa: E501
        if 'werkgevernummer' in local_var_params and local_var_params['werkgevernummer'] is not None:  # noqa: E501
            query_params.append(('werkgevernummer', local_var_params['werkgevernummer']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['HTTPBasic']  # noqa: E501

        return self.api_client.call_api(
            '/v2/search/core/{administratie}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Contact]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_search_pere_v2_search_pere_administratie_get(self, administratie, **kwargs):  # noqa: E501
        """Get Search Pere  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_search_pere_v2_search_pere_administratie_get(administratie, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str administratie: (required)
        :param str burgerservicenummer:
        :param str naam:
        :param str relatienummer:
        :param str geboortedatum:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Contact]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_search_pere_v2_search_pere_administratie_get_with_http_info(administratie, **kwargs)  # noqa: E501

    def get_search_pere_v2_search_pere_administratie_get_with_http_info(self, administratie, **kwargs):  # noqa: E501
        """Get Search Pere  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_search_pere_v2_search_pere_administratie_get_with_http_info(administratie, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str administratie: (required)
        :param str burgerservicenummer:
        :param str naam:
        :param str relatienummer:
        :param str geboortedatum:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Contact], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'administratie',
            'burgerservicenummer',
            'naam',
            'relatienummer',
            'geboortedatum'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_search_pere_v2_search_pere_administratie_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'administratie' is set
        if self.api_client.client_side_validation and ('administratie' not in local_var_params or  # noqa: E501
                                                        local_var_params['administratie'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `administratie` when calling `get_search_pere_v2_search_pere_administratie_get`")  # noqa: E501

        if self.api_client.client_side_validation and ('burgerservicenummer' in local_var_params and  # noqa: E501
                                                        len(local_var_params['burgerservicenummer']) < 3):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `burgerservicenummer` when calling `get_search_pere_v2_search_pere_administratie_get`, length must be greater than or equal to `3`")  # noqa: E501
        if self.api_client.client_side_validation and 'burgerservicenummer' in local_var_params and not re.search(r'\d+', local_var_params['burgerservicenummer']):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `burgerservicenummer` when calling `get_search_pere_v2_search_pere_administratie_get`, must conform to the pattern `/\d+/`")  # noqa: E501
        if self.api_client.client_side_validation and ('naam' in local_var_params and  # noqa: E501
                                                        len(local_var_params['naam']) < 3):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `naam` when calling `get_search_pere_v2_search_pere_administratie_get`, length must be greater than or equal to `3`")  # noqa: E501
        if self.api_client.client_side_validation and 'relatienummer' in local_var_params and not re.search(r'\d+', local_var_params['relatienummer']):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `relatienummer` when calling `get_search_pere_v2_search_pere_administratie_get`, must conform to the pattern `/\d+/`")  # noqa: E501
        if self.api_client.client_side_validation and 'geboortedatum' in local_var_params and not re.search(r'\d+-\d+-\d+', local_var_params['geboortedatum']):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `geboortedatum` when calling `get_search_pere_v2_search_pere_administratie_get`, must conform to the pattern `/\d+-\d+-\d+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'administratie' in local_var_params:
            path_params['administratie'] = local_var_params['administratie']  # noqa: E501

        query_params = []
        if 'burgerservicenummer' in local_var_params and local_var_params['burgerservicenummer'] is not None:  # noqa: E501
            query_params.append(('burgerservicenummer', local_var_params['burgerservicenummer']))  # noqa: E501
        if 'naam' in local_var_params and local_var_params['naam'] is not None:  # noqa: E501
            query_params.append(('naam', local_var_params['naam']))  # noqa: E501
        if 'relatienummer' in local_var_params and local_var_params['relatienummer'] is not None:  # noqa: E501
            query_params.append(('relatienummer', local_var_params['relatienummer']))  # noqa: E501
        if 'geboortedatum' in local_var_params and local_var_params['geboortedatum'] is not None:  # noqa: E501
            query_params.append(('geboortedatum', local_var_params['geboortedatum']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['HTTPBasic']  # noqa: E501

        return self.api_client.call_api(
            '/v2/search/pere/{administratie}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Contact]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_snapshot_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_get(self, administratie, relatiesoort, persoonsnummer, **kwargs):  # noqa: E501
        """Get Snapshot  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_snapshot_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_get(administratie, relatiesoort, persoonsnummer, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str administratie: (required)
        :param str relatiesoort: (required)
        :param str persoonsnummer: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AnyOfPersoonContactGegevensContactpersoonGegevensWerkgegeverContactGegevens
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_snapshot_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_get_with_http_info(administratie, relatiesoort, persoonsnummer, **kwargs)  # noqa: E501

    def get_snapshot_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_get_with_http_info(self, administratie, relatiesoort, persoonsnummer, **kwargs):  # noqa: E501
        """Get Snapshot  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_snapshot_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_get_with_http_info(administratie, relatiesoort, persoonsnummer, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str administratie: (required)
        :param str relatiesoort: (required)
        :param str persoonsnummer: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AnyOfPersoonContactGegevensContactpersoonGegevensWerkgegeverContactGegevens, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'administratie',
            'relatiesoort',
            'persoonsnummer'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_snapshot_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'administratie' is set
        if self.api_client.client_side_validation and ('administratie' not in local_var_params or  # noqa: E501
                                                        local_var_params['administratie'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `administratie` when calling `get_snapshot_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_get`")  # noqa: E501
        # verify the required parameter 'relatiesoort' is set
        if self.api_client.client_side_validation and ('relatiesoort' not in local_var_params or  # noqa: E501
                                                        local_var_params['relatiesoort'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `relatiesoort` when calling `get_snapshot_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_get`")  # noqa: E501
        # verify the required parameter 'persoonsnummer' is set
        if self.api_client.client_side_validation and ('persoonsnummer' not in local_var_params or  # noqa: E501
                                                        local_var_params['persoonsnummer'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `persoonsnummer` when calling `get_snapshot_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_get`")  # noqa: E501

        if self.api_client.client_side_validation and 'persoonsnummer' in local_var_params and not re.search(r'^(?:CON-)?(\d+)$', local_var_params['persoonsnummer']):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `persoonsnummer` when calling `get_snapshot_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_get`, must conform to the pattern `/^(?:CON-)?(\d+)$/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'administratie' in local_var_params:
            path_params['administratie'] = local_var_params['administratie']  # noqa: E501
        if 'relatiesoort' in local_var_params:
            path_params['relatiesoort'] = local_var_params['relatiesoort']  # noqa: E501
        if 'persoonsnummer' in local_var_params:
            path_params['persoonsnummer'] = local_var_params['persoonsnummer']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['HTTPBasic']  # noqa: E501

        return self.api_client.call_api(
            '/v2/contactgegevens/{administratie}/{relatiesoort}/{persoonsnummer}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AnyOfPersoonContactGegevensContactpersoonGegevensWerkgegeverContactGegevens',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def put_event_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_events_post(self, administratie, relatiesoort, persoonsnummer, contactgegevens_event_input, **kwargs):  # noqa: E501
        """Put Event  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_event_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_events_post(administratie, relatiesoort, persoonsnummer, contactgegevens_event_input, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str administratie: (required)
        :param str relatiesoort: (required)
        :param str persoonsnummer: (required)
        :param ContactgegevensEventInput contactgegevens_event_input: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ContactgegevensEvent
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.put_event_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_events_post_with_http_info(administratie, relatiesoort, persoonsnummer, contactgegevens_event_input, **kwargs)  # noqa: E501

    def put_event_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_events_post_with_http_info(self, administratie, relatiesoort, persoonsnummer, contactgegevens_event_input, **kwargs):  # noqa: E501
        """Put Event  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_event_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_events_post_with_http_info(administratie, relatiesoort, persoonsnummer, contactgegevens_event_input, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str administratie: (required)
        :param str relatiesoort: (required)
        :param str persoonsnummer: (required)
        :param ContactgegevensEventInput contactgegevens_event_input: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ContactgegevensEvent, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'administratie',
            'relatiesoort',
            'persoonsnummer',
            'contactgegevens_event_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_event_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_events_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'administratie' is set
        if self.api_client.client_side_validation and ('administratie' not in local_var_params or  # noqa: E501
                                                        local_var_params['administratie'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `administratie` when calling `put_event_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_events_post`")  # noqa: E501
        # verify the required parameter 'relatiesoort' is set
        if self.api_client.client_side_validation and ('relatiesoort' not in local_var_params or  # noqa: E501
                                                        local_var_params['relatiesoort'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `relatiesoort` when calling `put_event_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_events_post`")  # noqa: E501
        # verify the required parameter 'persoonsnummer' is set
        if self.api_client.client_side_validation and ('persoonsnummer' not in local_var_params or  # noqa: E501
                                                        local_var_params['persoonsnummer'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `persoonsnummer` when calling `put_event_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_events_post`")  # noqa: E501
        # verify the required parameter 'contactgegevens_event_input' is set
        if self.api_client.client_side_validation and ('contactgegevens_event_input' not in local_var_params or  # noqa: E501
                                                        local_var_params['contactgegevens_event_input'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `contactgegevens_event_input` when calling `put_event_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_events_post`")  # noqa: E501

        if self.api_client.client_side_validation and 'persoonsnummer' in local_var_params and not re.search(r'^(?:CON-)?(\d+)$', local_var_params['persoonsnummer']):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `persoonsnummer` when calling `put_event_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_events_post`, must conform to the pattern `/^(?:CON-)?(\d+)$/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'administratie' in local_var_params:
            path_params['administratie'] = local_var_params['administratie']  # noqa: E501
        if 'relatiesoort' in local_var_params:
            path_params['relatiesoort'] = local_var_params['relatiesoort']  # noqa: E501
        if 'persoonsnummer' in local_var_params:
            path_params['persoonsnummer'] = local_var_params['persoonsnummer']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'contactgegevens_event_input' in local_var_params:
            body_params = local_var_params['contactgegevens_event_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['HTTPBasic']  # noqa: E501

        return self.api_client.call_api(
            '/v2/contactgegevens/{administratie}/{relatiesoort}/{persoonsnummer}/events', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ContactgegevensEvent',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    MN Frontoffice CORE & PERE

    Highly available and searchable datastore for MN  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from frontoffice.configuration import Configuration


class ContactpersoonGegevens(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'email': 'str',
        'adressen': 'list[AdresMutatie]',
        'kanaalvoorkeur': 'str',
        'nieuwsbrief': 'bool',
        'klanttevredenheidsonderzoek': 'bool',
        'magazine': 'str',
        'telefoonnummer1': 'str',
        'telefoonnummer2': 'str',
        'email_adresseerbaar': 'bool',
        'voornaam': 'str',
        'achternaam': 'str',
        'werkgevernummer': 'str',
        'functie': 'str',
        'actief': 'bool',
        'aanhef': 'str',
        'tussenvoegsel': 'str'
    }

    attribute_map = {
        'email': 'email',
        'adressen': 'adressen',
        'kanaalvoorkeur': 'kanaalvoorkeur',
        'nieuwsbrief': 'nieuwsbrief',
        'klanttevredenheidsonderzoek': 'klanttevredenheidsonderzoek',
        'magazine': 'magazine',
        'telefoonnummer1': 'telefoonnummer1',
        'telefoonnummer2': 'telefoonnummer2',
        'email_adresseerbaar': 'emailAdresseerbaar',
        'voornaam': 'voornaam',
        'achternaam': 'achternaam',
        'werkgevernummer': 'werkgevernummer',
        'functie': 'functie',
        'actief': 'actief',
        'aanhef': 'aanhef',
        'tussenvoegsel': 'tussenvoegsel'
    }

    def __init__(self, email=None, adressen=[], kanaalvoorkeur=None, nieuwsbrief=None, klanttevredenheidsonderzoek=None, magazine=None, telefoonnummer1=None, telefoonnummer2=None, email_adresseerbaar=None, voornaam=None, achternaam=None, werkgevernummer=None, functie=None, actief=None, aanhef=None, tussenvoegsel=None, local_vars_configuration=None):  # noqa: E501
        """ContactpersoonGegevens - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._email = None
        self._adressen = None
        self._kanaalvoorkeur = None
        self._nieuwsbrief = None
        self._klanttevredenheidsonderzoek = None
        self._magazine = None
        self._telefoonnummer1 = None
        self._telefoonnummer2 = None
        self._email_adresseerbaar = None
        self._voornaam = None
        self._achternaam = None
        self._werkgevernummer = None
        self._functie = None
        self._actief = None
        self._aanhef = None
        self._tussenvoegsel = None
        self.discriminator = None

        if email is not None:
            self.email = email
        if adressen is not None:
            self.adressen = adressen
        if kanaalvoorkeur is not None:
            self.kanaalvoorkeur = kanaalvoorkeur
        if nieuwsbrief is not None:
            self.nieuwsbrief = nieuwsbrief
        if klanttevredenheidsonderzoek is not None:
            self.klanttevredenheidsonderzoek = klanttevredenheidsonderzoek
        if magazine is not None:
            self.magazine = magazine
        if telefoonnummer1 is not None:
            self.telefoonnummer1 = telefoonnummer1
        if telefoonnummer2 is not None:
            self.telefoonnummer2 = telefoonnummer2
        if email_adresseerbaar is not None:
            self.email_adresseerbaar = email_adresseerbaar
        if voornaam is not None:
            self.voornaam = voornaam
        if achternaam is not None:
            self.achternaam = achternaam
        if werkgevernummer is not None:
            self.werkgevernummer = werkgevernummer
        if functie is not None:
            self.functie = functie
        if actief is not None:
            self.actief = actief
        if aanhef is not None:
            self.aanhef = aanhef
        if tussenvoegsel is not None:
            self.tussenvoegsel = tussenvoegsel

    @property
    def email(self):
        """Gets the email of this ContactpersoonGegevens.  # noqa: E501


        :return: The email of this ContactpersoonGegevens.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this ContactpersoonGegevens.


        :param email: The email of this ContactpersoonGegevens.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def adressen(self):
        """Gets the adressen of this ContactpersoonGegevens.  # noqa: E501


        :return: The adressen of this ContactpersoonGegevens.  # noqa: E501
        :rtype: list[AdresMutatie]
        """
        return self._adressen

    @adressen.setter
    def adressen(self, adressen):
        """Sets the adressen of this ContactpersoonGegevens.


        :param adressen: The adressen of this ContactpersoonGegevens.  # noqa: E501
        :type: list[AdresMutatie]
        """

        self._adressen = adressen

    @property
    def kanaalvoorkeur(self):
        """Gets the kanaalvoorkeur of this ContactpersoonGegevens.  # noqa: E501


        :return: The kanaalvoorkeur of this ContactpersoonGegevens.  # noqa: E501
        :rtype: str
        """
        return self._kanaalvoorkeur

    @kanaalvoorkeur.setter
    def kanaalvoorkeur(self, kanaalvoorkeur):
        """Sets the kanaalvoorkeur of this ContactpersoonGegevens.


        :param kanaalvoorkeur: The kanaalvoorkeur of this ContactpersoonGegevens.  # noqa: E501
        :type: str
        """
        allowed_values = ["POST", "PORTAAL"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and kanaalvoorkeur not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `kanaalvoorkeur` ({0}), must be one of {1}"  # noqa: E501
                .format(kanaalvoorkeur, allowed_values)
            )

        self._kanaalvoorkeur = kanaalvoorkeur

    @property
    def nieuwsbrief(self):
        """Gets the nieuwsbrief of this ContactpersoonGegevens.  # noqa: E501


        :return: The nieuwsbrief of this ContactpersoonGegevens.  # noqa: E501
        :rtype: bool
        """
        return self._nieuwsbrief

    @nieuwsbrief.setter
    def nieuwsbrief(self, nieuwsbrief):
        """Sets the nieuwsbrief of this ContactpersoonGegevens.


        :param nieuwsbrief: The nieuwsbrief of this ContactpersoonGegevens.  # noqa: E501
        :type: bool
        """

        self._nieuwsbrief = nieuwsbrief

    @property
    def klanttevredenheidsonderzoek(self):
        """Gets the klanttevredenheidsonderzoek of this ContactpersoonGegevens.  # noqa: E501


        :return: The klanttevredenheidsonderzoek of this ContactpersoonGegevens.  # noqa: E501
        :rtype: bool
        """
        return self._klanttevredenheidsonderzoek

    @klanttevredenheidsonderzoek.setter
    def klanttevredenheidsonderzoek(self, klanttevredenheidsonderzoek):
        """Sets the klanttevredenheidsonderzoek of this ContactpersoonGegevens.


        :param klanttevredenheidsonderzoek: The klanttevredenheidsonderzoek of this ContactpersoonGegevens.  # noqa: E501
        :type: bool
        """

        self._klanttevredenheidsonderzoek = klanttevredenheidsonderzoek

    @property
    def magazine(self):
        """Gets the magazine of this ContactpersoonGegevens.  # noqa: E501


        :return: The magazine of this ContactpersoonGegevens.  # noqa: E501
        :rtype: str
        """
        return self._magazine

    @magazine.setter
    def magazine(self, magazine):
        """Sets the magazine of this ContactpersoonGegevens.


        :param magazine: The magazine of this ContactpersoonGegevens.  # noqa: E501
        :type: str
        """
        allowed_values = ["POST", "PORTAAL"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and magazine not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `magazine` ({0}), must be one of {1}"  # noqa: E501
                .format(magazine, allowed_values)
            )

        self._magazine = magazine

    @property
    def telefoonnummer1(self):
        """Gets the telefoonnummer1 of this ContactpersoonGegevens.  # noqa: E501


        :return: The telefoonnummer1 of this ContactpersoonGegevens.  # noqa: E501
        :rtype: str
        """
        return self._telefoonnummer1

    @telefoonnummer1.setter
    def telefoonnummer1(self, telefoonnummer1):
        """Sets the telefoonnummer1 of this ContactpersoonGegevens.


        :param telefoonnummer1: The telefoonnummer1 of this ContactpersoonGegevens.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                telefoonnummer1 is not None and not re.search(r'^[+]?[\-\d]+$', telefoonnummer1)):  # noqa: E501
            raise ValueError(r"Invalid value for `telefoonnummer1`, must be a follow pattern or equal to `/^[+]?[\-\d]+$/`")  # noqa: E501

        self._telefoonnummer1 = telefoonnummer1

    @property
    def telefoonnummer2(self):
        """Gets the telefoonnummer2 of this ContactpersoonGegevens.  # noqa: E501


        :return: The telefoonnummer2 of this ContactpersoonGegevens.  # noqa: E501
        :rtype: str
        """
        return self._telefoonnummer2

    @telefoonnummer2.setter
    def telefoonnummer2(self, telefoonnummer2):
        """Sets the telefoonnummer2 of this ContactpersoonGegevens.


        :param telefoonnummer2: The telefoonnummer2 of this ContactpersoonGegevens.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                telefoonnummer2 is not None and not re.search(r'^[+]?[\-\d]+$', telefoonnummer2)):  # noqa: E501
            raise ValueError(r"Invalid value for `telefoonnummer2`, must be a follow pattern or equal to `/^[+]?[\-\d]+$/`")  # noqa: E501

        self._telefoonnummer2 = telefoonnummer2

    @property
    def email_adresseerbaar(self):
        """Gets the email_adresseerbaar of this ContactpersoonGegevens.  # noqa: E501


        :return: The email_adresseerbaar of this ContactpersoonGegevens.  # noqa: E501
        :rtype: bool
        """
        return self._email_adresseerbaar

    @email_adresseerbaar.setter
    def email_adresseerbaar(self, email_adresseerbaar):
        """Sets the email_adresseerbaar of this ContactpersoonGegevens.


        :param email_adresseerbaar: The email_adresseerbaar of this ContactpersoonGegevens.  # noqa: E501
        :type: bool
        """

        self._email_adresseerbaar = email_adresseerbaar

    @property
    def voornaam(self):
        """Gets the voornaam of this ContactpersoonGegevens.  # noqa: E501


        :return: The voornaam of this ContactpersoonGegevens.  # noqa: E501
        :rtype: str
        """
        return self._voornaam

    @voornaam.setter
    def voornaam(self, voornaam):
        """Sets the voornaam of this ContactpersoonGegevens.


        :param voornaam: The voornaam of this ContactpersoonGegevens.  # noqa: E501
        :type: str
        """

        self._voornaam = voornaam

    @property
    def achternaam(self):
        """Gets the achternaam of this ContactpersoonGegevens.  # noqa: E501


        :return: The achternaam of this ContactpersoonGegevens.  # noqa: E501
        :rtype: str
        """
        return self._achternaam

    @achternaam.setter
    def achternaam(self, achternaam):
        """Sets the achternaam of this ContactpersoonGegevens.


        :param achternaam: The achternaam of this ContactpersoonGegevens.  # noqa: E501
        :type: str
        """

        self._achternaam = achternaam

    @property
    def werkgevernummer(self):
        """Gets the werkgevernummer of this ContactpersoonGegevens.  # noqa: E501


        :return: The werkgevernummer of this ContactpersoonGegevens.  # noqa: E501
        :rtype: str
        """
        return self._werkgevernummer

    @werkgevernummer.setter
    def werkgevernummer(self, werkgevernummer):
        """Sets the werkgevernummer of this ContactpersoonGegevens.


        :param werkgevernummer: The werkgevernummer of this ContactpersoonGegevens.  # noqa: E501
        :type: str
        """

        self._werkgevernummer = werkgevernummer

    @property
    def functie(self):
        """Gets the functie of this ContactpersoonGegevens.  # noqa: E501


        :return: The functie of this ContactpersoonGegevens.  # noqa: E501
        :rtype: str
        """
        return self._functie

    @functie.setter
    def functie(self, functie):
        """Sets the functie of this ContactpersoonGegevens.


        :param functie: The functie of this ContactpersoonGegevens.  # noqa: E501
        :type: str
        """

        self._functie = functie

    @property
    def actief(self):
        """Gets the actief of this ContactpersoonGegevens.  # noqa: E501


        :return: The actief of this ContactpersoonGegevens.  # noqa: E501
        :rtype: bool
        """
        return self._actief

    @actief.setter
    def actief(self, actief):
        """Sets the actief of this ContactpersoonGegevens.


        :param actief: The actief of this ContactpersoonGegevens.  # noqa: E501
        :type: bool
        """

        self._actief = actief

    @property
    def aanhef(self):
        """Gets the aanhef of this ContactpersoonGegevens.  # noqa: E501


        :return: The aanhef of this ContactpersoonGegevens.  # noqa: E501
        :rtype: str
        """
        return self._aanhef

    @aanhef.setter
    def aanhef(self, aanhef):
        """Sets the aanhef of this ContactpersoonGegevens.


        :param aanhef: The aanhef of this ContactpersoonGegevens.  # noqa: E501
        :type: str
        """

        self._aanhef = aanhef

    @property
    def tussenvoegsel(self):
        """Gets the tussenvoegsel of this ContactpersoonGegevens.  # noqa: E501


        :return: The tussenvoegsel of this ContactpersoonGegevens.  # noqa: E501
        :rtype: str
        """
        return self._tussenvoegsel

    @tussenvoegsel.setter
    def tussenvoegsel(self, tussenvoegsel):
        """Sets the tussenvoegsel of this ContactpersoonGegevens.


        :param tussenvoegsel: The tussenvoegsel of this ContactpersoonGegevens.  # noqa: E501
        :type: str
        """

        self._tussenvoegsel = tussenvoegsel

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ContactpersoonGegevens):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ContactpersoonGegevens):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    MN Frontoffice CORE & PERE

    Highly available and searchable datastore for MN  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from frontoffice.models.adres_mutatie import AdresMutatie
from frontoffice.models.contact import Contact
from frontoffice.models.contactgegevens_event import ContactgegevensEvent
from frontoffice.models.contactgegevens_event_input import ContactgegevensEventInput
from frontoffice.models.contactpersoon_gegevens import ContactpersoonGegevens
from frontoffice.models.datum_delen import DatumDelen
from frontoffice.models.http_validation_error import HTTPValidationError
from frontoffice.models.partnerschap import Partnerschap
from frontoffice.models.persoon_contact_gegevens import PersoonContactGegevens
from frontoffice.models.persoons_gegevens import PersoonsGegevens
from frontoffice.models.persoons_gegevens_basic import PersoonsGegevensBasic
from frontoffice.models.settings import Settings
from frontoffice.models.validation_error import ValidationError
from frontoffice.models.werkgegever_contact_gegevens import WerkgegeverContactGegevens



# coding: utf-8

"""
    MN Frontoffice CORE & PERE

    Highly available and searchable datastore for MN  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from frontoffice.configuration import Configuration


class Settings(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'env': 'str',
        'runtime': 'str'
    }

    attribute_map = {
        'env': 'env',
        'runtime': 'runtime'
    }

    def __init__(self, env='fb', runtime='basic', local_vars_configuration=None):  # noqa: E501
        """Settings - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._env = None
        self._runtime = None
        self.discriminator = None

        if env is not None:
            self.env = env
        if runtime is not None:
            self.runtime = runtime

    @property
    def env(self):
        """Gets the env of this Settings.  # noqa: E501


        :return: The env of this Settings.  # noqa: E501
        :rtype: str
        """
        return self._env

    @env.setter
    def env(self, env):
        """Sets the env of this Settings.


        :param env: The env of this Settings.  # noqa: E501
        :type: str
        """

        self._env = env

    @property
    def runtime(self):
        """Gets the runtime of this Settings.  # noqa: E501


        :return: The runtime of this Settings.  # noqa: E501
        :rtype: str
        """
        return self._runtime

    @runtime.setter
    def runtime(self, runtime):
        """Sets the runtime of this Settings.


        :param runtime: The runtime of this Settings.  # noqa: E501
        :type: str
        """
        allowed_values = ["basic", "lambda", "serverless", "docker", "Unknown"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and runtime not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `runtime` ({0}), must be one of {1}"  # noqa: E501
                .format(runtime, allowed_values)
            )

        self._runtime = runtime

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Settings):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Settings):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    MN Frontoffice CORE & PERE

    Highly available and searchable datastore for MN  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from frontoffice.api.contactgegevens_api import ContactgegevensApi
from frontoffice.api.developer_tools_api import DeveloperToolsApi
from frontoffice.api.persoonsgegevens_api import PersoonsgegevensApi

# import ApiClient
from frontoffice.api_client import ApiClient
from frontoffice.configuration import Configuration
from frontoffice.exceptions import OpenApiException
from frontoffice.exceptions import ApiTypeError
from frontoffice.exceptions import ApiValueError
from frontoffice.exceptions import ApiKeyError
from frontoffice.exceptions import ApiAttributeError
from frontoffice.exceptions import ApiException
# import models into sdk package
from frontoffice.models.adres_mutatie import AdresMutatie
from frontoffice.models.contact import Contact
from frontoffice.models.contactgegevens_event import ContactgegevensEvent
from frontoffice.models.contactgegevens_event_input import ContactgegevensEventInput
from frontoffice.models.contactpersoon_gegevens import ContactpersoonGegevens
from frontoffice.models.datum_delen import DatumDelen
from frontoffice.models.http_validation_error import HTTPValidationError
from frontoffice.models.partnerschap import Partnerschap
from frontoffice.models.persoon_contact_gegevens import PersoonContactGegevens
from frontoffice.models.persoons_gegevens import PersoonsGegevens
from frontoffice.models.persoons_gegevens_basic import PersoonsGegevensBasic
from frontoffice.models.settings import Settings
from frontoffice.models.validation_error import ValidationError
from frontoffice.models.werkgegever_contact_gegevens import WerkgegeverContactGegevens




# coding: utf-8

"""
    MN Frontoffice CORE & PERE

    Highly available and searchable datastore for MN  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from frontoffice.configuration import Configuration


class ContactgegevensEventInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'bron': 'str',
        'correlatie_id': 'str',
        'event_datum_bron': 'datetime',
        'event_title': 'str',
        'indiener': 'str',
        'event_payload': 'AnyOfPersoonContactGegevensContactpersoonGegevensWerkgegeverContactGegevens'
    }

    attribute_map = {
        'bron': 'bron',
        'correlatie_id': 'correlatie_id',
        'event_datum_bron': 'event_datum_bron',
        'event_title': 'event_title',
        'indiener': 'indiener',
        'event_payload': 'event_payload'
    }

    def __init__(self, bron=None, correlatie_id=None, event_datum_bron=None, event_title=None, indiener=None, event_payload=None, local_vars_configuration=None):  # noqa: E501
        """ContactgegevensEventInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._bron = None
        self._correlatie_id = None
        self._event_datum_bron = None
        self._event_title = None
        self._indiener = None
        self._event_payload = None
        self.discriminator = None

        self.bron = bron
        self.correlatie_id = correlatie_id
        self.event_datum_bron = event_datum_bron
        self.event_title = event_title
        self.indiener = indiener
        self.event_payload = event_payload

    @property
    def bron(self):
        """Gets the bron of this ContactgegevensEventInput.  # noqa: E501


        :return: The bron of this ContactgegevensEventInput.  # noqa: E501
        :rtype: str
        """
        return self._bron

    @bron.setter
    def bron(self, bron):
        """Sets the bron of this ContactgegevensEventInput.


        :param bron: The bron of this ContactgegevensEventInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and bron is None:  # noqa: E501
            raise ValueError("Invalid value for `bron`, must not be `None`")  # noqa: E501

        self._bron = bron

    @property
    def correlatie_id(self):
        """Gets the correlatie_id of this ContactgegevensEventInput.  # noqa: E501


        :return: The correlatie_id of this ContactgegevensEventInput.  # noqa: E501
        :rtype: str
        """
        return self._correlatie_id

    @correlatie_id.setter
    def correlatie_id(self, correlatie_id):
        """Sets the correlatie_id of this ContactgegevensEventInput.


        :param correlatie_id: The correlatie_id of this ContactgegevensEventInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and correlatie_id is None:  # noqa: E501
            raise ValueError("Invalid value for `correlatie_id`, must not be `None`")  # noqa: E501

        self._correlatie_id = correlatie_id

    @property
    def event_datum_bron(self):
        """Gets the event_datum_bron of this ContactgegevensEventInput.  # noqa: E501


        :return: The event_datum_bron of this ContactgegevensEventInput.  # noqa: E501
        :rtype: datetime
        """
        return self._event_datum_bron

    @event_datum_bron.setter
    def event_datum_bron(self, event_datum_bron):
        """Sets the event_datum_bron of this ContactgegevensEventInput.


        :param event_datum_bron: The event_datum_bron of this ContactgegevensEventInput.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and event_datum_bron is None:  # noqa: E501
            raise ValueError("Invalid value for `event_datum_bron`, must not be `None`")  # noqa: E501

        self._event_datum_bron = event_datum_bron

    @property
    def event_title(self):
        """Gets the event_title of this ContactgegevensEventInput.  # noqa: E501


        :return: The event_title of this ContactgegevensEventInput.  # noqa: E501
        :rtype: str
        """
        return self._event_title

    @event_title.setter
    def event_title(self, event_title):
        """Sets the event_title of this ContactgegevensEventInput.


        :param event_title: The event_title of this ContactgegevensEventInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and event_title is None:  # noqa: E501
            raise ValueError("Invalid value for `event_title`, must not be `None`")  # noqa: E501

        self._event_title = event_title

    @property
    def indiener(self):
        """Gets the indiener of this ContactgegevensEventInput.  # noqa: E501


        :return: The indiener of this ContactgegevensEventInput.  # noqa: E501
        :rtype: str
        """
        return self._indiener

    @indiener.setter
    def indiener(self, indiener):
        """Sets the indiener of this ContactgegevensEventInput.


        :param indiener: The indiener of this ContactgegevensEventInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and indiener is None:  # noqa: E501
            raise ValueError("Invalid value for `indiener`, must not be `None`")  # noqa: E501

        self._indiener = indiener

    @property
    def event_payload(self):
        """Gets the event_payload of this ContactgegevensEventInput.  # noqa: E501


        :return: The event_payload of this ContactgegevensEventInput.  # noqa: E501
        :rtype: AnyOfPersoonContactGegevensContactpersoonGegevensWerkgegeverContactGegevens
        """
        return self._event_payload

    @event_payload.setter
    def event_payload(self, event_payload):
        """Sets the event_payload of this ContactgegevensEventInput.


        :param event_payload: The event_payload of this ContactgegevensEventInput.  # noqa: E501
        :type: AnyOfPersoonContactGegevensContactpersoonGegevensWerkgegeverContactGegevens
        """
        if self.local_vars_configuration.client_side_validation and event_payload is None:  # noqa: E501
            raise ValueError("Invalid value for `event_payload`, must not be `None`")  # noqa: E501

        self._event_payload = event_payload

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ContactgegevensEventInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ContactgegevensEventInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MN Frontoffice CORE & PERE

    Highly available and searchable datastore for MN  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from frontoffice.configuration import Configuration


class AdresMutatie(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'soort': 'str',
        'postcode': 'str',
        'straat': 'str',
        'land': 'str',
        'huisnummer': 'int',
        'huisnummertoevoeging': 'str',
        'landnaam': 'str',
        'verwijderd': 'bool',
        'einddatum': 'str'
    }

    attribute_map = {
        'soort': 'soort',
        'postcode': 'postcode',
        'straat': 'straat',
        'land': 'land',
        'huisnummer': 'huisnummer',
        'huisnummertoevoeging': 'huisnummertoevoeging',
        'landnaam': 'landnaam',
        'verwijderd': 'verwijderd',
        'einddatum': 'einddatum'
    }

    def __init__(self, soort=None, postcode=None, straat=None, land=None, huisnummer=None, huisnummertoevoeging=None, landnaam=None, verwijderd=None, einddatum=None, local_vars_configuration=None):  # noqa: E501
        """AdresMutatie - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._soort = None
        self._postcode = None
        self._straat = None
        self._land = None
        self._huisnummer = None
        self._huisnummertoevoeging = None
        self._landnaam = None
        self._verwijderd = None
        self._einddatum = None
        self.discriminator = None

        self.soort = soort
        if postcode is not None:
            self.postcode = postcode
        if straat is not None:
            self.straat = straat
        if land is not None:
            self.land = land
        if huisnummer is not None:
            self.huisnummer = huisnummer
        if huisnummertoevoeging is not None:
            self.huisnummertoevoeging = huisnummertoevoeging
        if landnaam is not None:
            self.landnaam = landnaam
        if verwijderd is not None:
            self.verwijderd = verwijderd
        if einddatum is not None:
            self.einddatum = einddatum

    @property
    def soort(self):
        """Gets the soort of this AdresMutatie.  # noqa: E501


        :return: The soort of this AdresMutatie.  # noqa: E501
        :rtype: str
        """
        return self._soort

    @soort.setter
    def soort(self, soort):
        """Sets the soort of this AdresMutatie.


        :param soort: The soort of this AdresMutatie.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and soort is None:  # noqa: E501
            raise ValueError("Invalid value for `soort`, must not be `None`")  # noqa: E501
        allowed_values = ["Domicilie", "Opgegeven", "Statutair", "Correspondentie"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and soort not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `soort` ({0}), must be one of {1}"  # noqa: E501
                .format(soort, allowed_values)
            )

        self._soort = soort

    @property
    def postcode(self):
        """Gets the postcode of this AdresMutatie.  # noqa: E501


        :return: The postcode of this AdresMutatie.  # noqa: E501
        :rtype: str
        """
        return self._postcode

    @postcode.setter
    def postcode(self, postcode):
        """Sets the postcode of this AdresMutatie.


        :param postcode: The postcode of this AdresMutatie.  # noqa: E501
        :type: str
        """

        self._postcode = postcode

    @property
    def straat(self):
        """Gets the straat of this AdresMutatie.  # noqa: E501


        :return: The straat of this AdresMutatie.  # noqa: E501
        :rtype: str
        """
        return self._straat

    @straat.setter
    def straat(self, straat):
        """Sets the straat of this AdresMutatie.


        :param straat: The straat of this AdresMutatie.  # noqa: E501
        :type: str
        """

        self._straat = straat

    @property
    def land(self):
        """Gets the land of this AdresMutatie.  # noqa: E501


        :return: The land of this AdresMutatie.  # noqa: E501
        :rtype: str
        """
        return self._land

    @land.setter
    def land(self, land):
        """Sets the land of this AdresMutatie.


        :param land: The land of this AdresMutatie.  # noqa: E501
        :type: str
        """

        self._land = land

    @property
    def huisnummer(self):
        """Gets the huisnummer of this AdresMutatie.  # noqa: E501


        :return: The huisnummer of this AdresMutatie.  # noqa: E501
        :rtype: int
        """
        return self._huisnummer

    @huisnummer.setter
    def huisnummer(self, huisnummer):
        """Sets the huisnummer of this AdresMutatie.


        :param huisnummer: The huisnummer of this AdresMutatie.  # noqa: E501
        :type: int
        """

        self._huisnummer = huisnummer

    @property
    def huisnummertoevoeging(self):
        """Gets the huisnummertoevoeging of this AdresMutatie.  # noqa: E501


        :return: The huisnummertoevoeging of this AdresMutatie.  # noqa: E501
        :rtype: str
        """
        return self._huisnummertoevoeging

    @huisnummertoevoeging.setter
    def huisnummertoevoeging(self, huisnummertoevoeging):
        """Sets the huisnummertoevoeging of this AdresMutatie.


        :param huisnummertoevoeging: The huisnummertoevoeging of this AdresMutatie.  # noqa: E501
        :type: str
        """

        self._huisnummertoevoeging = huisnummertoevoeging

    @property
    def landnaam(self):
        """Gets the landnaam of this AdresMutatie.  # noqa: E501


        :return: The landnaam of this AdresMutatie.  # noqa: E501
        :rtype: str
        """
        return self._landnaam

    @landnaam.setter
    def landnaam(self, landnaam):
        """Sets the landnaam of this AdresMutatie.


        :param landnaam: The landnaam of this AdresMutatie.  # noqa: E501
        :type: str
        """

        self._landnaam = landnaam

    @property
    def verwijderd(self):
        """Gets the verwijderd of this AdresMutatie.  # noqa: E501


        :return: The verwijderd of this AdresMutatie.  # noqa: E501
        :rtype: bool
        """
        return self._verwijderd

    @verwijderd.setter
    def verwijderd(self, verwijderd):
        """Sets the verwijderd of this AdresMutatie.


        :param verwijderd: The verwijderd of this AdresMutatie.  # noqa: E501
        :type: bool
        """

        self._verwijderd = verwijderd

    @property
    def einddatum(self):
        """Gets the einddatum of this AdresMutatie.  # noqa: E501


        :return: The einddatum of this AdresMutatie.  # noqa: E501
        :rtype: str
        """
        return self._einddatum

    @einddatum.setter
    def einddatum(self, einddatum):
        """Sets the einddatum of this AdresMutatie.


        :param einddatum: The einddatum of this AdresMutatie.  # noqa: E501
        :type: str
        """

        self._einddatum = einddatum

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdresMutatie):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AdresMutatie):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from frontoffice.api.contactgegevens_api import ContactgegevensApi
from frontoffice.api.developer_tools_api import DeveloperToolsApi
from frontoffice.api.persoonsgegevens_api import PersoonsgegevensApi



# coding: utf-8

"""
    MN Frontoffice CORE & PERE

    Highly available and searchable datastore for MN  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from frontoffice.configuration import Configuration


class PersoonsGegevensBasic(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'burgerservicenummer': 'str',
        'persoonsnummer': 'str',
        'relatienummer': 'str',
        'anummer': 'str',
        'naam': 'str',
        'voornamen': 'str',
        'voorlettes': 'str',
        'voorvoegsels': 'str',
        'naamgebruik': 'str',
        'opgemaakte_naam': 'str',
        'voorkeursnaam': 'str',
        'geboortedatum': 'DatumDelen',
        'overlijdensdatum': 'DatumDelen',
        'geslacht': 'str',
        'partner_naam': 'str',
        'partner_voorvoegsels': 'str'
    }

    attribute_map = {
        'burgerservicenummer': 'burgerservicenummer',
        'persoonsnummer': 'persoonsnummer',
        'relatienummer': 'relatienummer',
        'anummer': 'anummer',
        'naam': 'naam',
        'voornamen': 'voornamen',
        'voorlettes': 'voorlettes',
        'voorvoegsels': 'voorvoegsels',
        'naamgebruik': 'naamgebruik',
        'opgemaakte_naam': 'opgemaakteNaam',
        'voorkeursnaam': 'voorkeursnaam',
        'geboortedatum': 'Geboortedatum',
        'overlijdensdatum': 'Overlijdensdatum',
        'geslacht': 'geslacht',
        'partner_naam': 'partnerNaam',
        'partner_voorvoegsels': 'partnerVoorvoegsels'
    }

    def __init__(self, burgerservicenummer=None, persoonsnummer=None, relatienummer=None, anummer=None, naam=None, voornamen=None, voorlettes=None, voorvoegsels=None, naamgebruik=None, opgemaakte_naam=None, voorkeursnaam=None, geboortedatum=None, overlijdensdatum=None, geslacht=None, partner_naam=None, partner_voorvoegsels=None, local_vars_configuration=None):  # noqa: E501
        """PersoonsGegevensBasic - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._burgerservicenummer = None
        self._persoonsnummer = None
        self._relatienummer = None
        self._anummer = None
        self._naam = None
        self._voornamen = None
        self._voorlettes = None
        self._voorvoegsels = None
        self._naamgebruik = None
        self._opgemaakte_naam = None
        self._voorkeursnaam = None
        self._geboortedatum = None
        self._overlijdensdatum = None
        self._geslacht = None
        self._partner_naam = None
        self._partner_voorvoegsels = None
        self.discriminator = None

        if burgerservicenummer is not None:
            self.burgerservicenummer = burgerservicenummer
        self.persoonsnummer = persoonsnummer
        if relatienummer is not None:
            self.relatienummer = relatienummer
        if anummer is not None:
            self.anummer = anummer
        if naam is not None:
            self.naam = naam
        if voornamen is not None:
            self.voornamen = voornamen
        if voorlettes is not None:
            self.voorlettes = voorlettes
        if voorvoegsels is not None:
            self.voorvoegsels = voorvoegsels
        if naamgebruik is not None:
            self.naamgebruik = naamgebruik
        if opgemaakte_naam is not None:
            self.opgemaakte_naam = opgemaakte_naam
        if voorkeursnaam is not None:
            self.voorkeursnaam = voorkeursnaam
        if geboortedatum is not None:
            self.geboortedatum = geboortedatum
        if overlijdensdatum is not None:
            self.overlijdensdatum = overlijdensdatum
        if geslacht is not None:
            self.geslacht = geslacht
        if partner_naam is not None:
            self.partner_naam = partner_naam
        if partner_voorvoegsels is not None:
            self.partner_voorvoegsels = partner_voorvoegsels

    @property
    def burgerservicenummer(self):
        """Gets the burgerservicenummer of this PersoonsGegevensBasic.  # noqa: E501


        :return: The burgerservicenummer of this PersoonsGegevensBasic.  # noqa: E501
        :rtype: str
        """
        return self._burgerservicenummer

    @burgerservicenummer.setter
    def burgerservicenummer(self, burgerservicenummer):
        """Sets the burgerservicenummer of this PersoonsGegevensBasic.


        :param burgerservicenummer: The burgerservicenummer of this PersoonsGegevensBasic.  # noqa: E501
        :type: str
        """

        self._burgerservicenummer = burgerservicenummer

    @property
    def persoonsnummer(self):
        """Gets the persoonsnummer of this PersoonsGegevensBasic.  # noqa: E501


        :return: The persoonsnummer of this PersoonsGegevensBasic.  # noqa: E501
        :rtype: str
        """
        return self._persoonsnummer

    @persoonsnummer.setter
    def persoonsnummer(self, persoonsnummer):
        """Sets the persoonsnummer of this PersoonsGegevensBasic.


        :param persoonsnummer: The persoonsnummer of this PersoonsGegevensBasic.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and persoonsnummer is None:  # noqa: E501
            raise ValueError("Invalid value for `persoonsnummer`, must not be `None`")  # noqa: E501

        self._persoonsnummer = persoonsnummer

    @property
    def relatienummer(self):
        """Gets the relatienummer of this PersoonsGegevensBasic.  # noqa: E501


        :return: The relatienummer of this PersoonsGegevensBasic.  # noqa: E501
        :rtype: str
        """
        return self._relatienummer

    @relatienummer.setter
    def relatienummer(self, relatienummer):
        """Sets the relatienummer of this PersoonsGegevensBasic.


        :param relatienummer: The relatienummer of this PersoonsGegevensBasic.  # noqa: E501
        :type: str
        """

        self._relatienummer = relatienummer

    @property
    def anummer(self):
        """Gets the anummer of this PersoonsGegevensBasic.  # noqa: E501


        :return: The anummer of this PersoonsGegevensBasic.  # noqa: E501
        :rtype: str
        """
        return self._anummer

    @anummer.setter
    def anummer(self, anummer):
        """Sets the anummer of this PersoonsGegevensBasic.


        :param anummer: The anummer of this PersoonsGegevensBasic.  # noqa: E501
        :type: str
        """

        self._anummer = anummer

    @property
    def naam(self):
        """Gets the naam of this PersoonsGegevensBasic.  # noqa: E501


        :return: The naam of this PersoonsGegevensBasic.  # noqa: E501
        :rtype: str
        """
        return self._naam

    @naam.setter
    def naam(self, naam):
        """Sets the naam of this PersoonsGegevensBasic.


        :param naam: The naam of this PersoonsGegevensBasic.  # noqa: E501
        :type: str
        """

        self._naam = naam

    @property
    def voornamen(self):
        """Gets the voornamen of this PersoonsGegevensBasic.  # noqa: E501


        :return: The voornamen of this PersoonsGegevensBasic.  # noqa: E501
        :rtype: str
        """
        return self._voornamen

    @voornamen.setter
    def voornamen(self, voornamen):
        """Sets the voornamen of this PersoonsGegevensBasic.


        :param voornamen: The voornamen of this PersoonsGegevensBasic.  # noqa: E501
        :type: str
        """

        self._voornamen = voornamen

    @property
    def voorlettes(self):
        """Gets the voorlettes of this PersoonsGegevensBasic.  # noqa: E501


        :return: The voorlettes of this PersoonsGegevensBasic.  # noqa: E501
        :rtype: str
        """
        return self._voorlettes

    @voorlettes.setter
    def voorlettes(self, voorlettes):
        """Sets the voorlettes of this PersoonsGegevensBasic.


        :param voorlettes: The voorlettes of this PersoonsGegevensBasic.  # noqa: E501
        :type: str
        """

        self._voorlettes = voorlettes

    @property
    def voorvoegsels(self):
        """Gets the voorvoegsels of this PersoonsGegevensBasic.  # noqa: E501


        :return: The voorvoegsels of this PersoonsGegevensBasic.  # noqa: E501
        :rtype: str
        """
        return self._voorvoegsels

    @voorvoegsels.setter
    def voorvoegsels(self, voorvoegsels):
        """Sets the voorvoegsels of this PersoonsGegevensBasic.


        :param voorvoegsels: The voorvoegsels of this PersoonsGegevensBasic.  # noqa: E501
        :type: str
        """

        self._voorvoegsels = voorvoegsels

    @property
    def naamgebruik(self):
        """Gets the naamgebruik of this PersoonsGegevensBasic.  # noqa: E501


        :return: The naamgebruik of this PersoonsGegevensBasic.  # noqa: E501
        :rtype: str
        """
        return self._naamgebruik

    @naamgebruik.setter
    def naamgebruik(self, naamgebruik):
        """Sets the naamgebruik of this PersoonsGegevensBasic.


        :param naamgebruik: The naamgebruik of this PersoonsGegevensBasic.  # noqa: E501
        :type: str
        """

        self._naamgebruik = naamgebruik

    @property
    def opgemaakte_naam(self):
        """Gets the opgemaakte_naam of this PersoonsGegevensBasic.  # noqa: E501


        :return: The opgemaakte_naam of this PersoonsGegevensBasic.  # noqa: E501
        :rtype: str
        """
        return self._opgemaakte_naam

    @opgemaakte_naam.setter
    def opgemaakte_naam(self, opgemaakte_naam):
        """Sets the opgemaakte_naam of this PersoonsGegevensBasic.


        :param opgemaakte_naam: The opgemaakte_naam of this PersoonsGegevensBasic.  # noqa: E501
        :type: str
        """

        self._opgemaakte_naam = opgemaakte_naam

    @property
    def voorkeursnaam(self):
        """Gets the voorkeursnaam of this PersoonsGegevensBasic.  # noqa: E501


        :return: The voorkeursnaam of this PersoonsGegevensBasic.  # noqa: E501
        :rtype: str
        """
        return self._voorkeursnaam

    @voorkeursnaam.setter
    def voorkeursnaam(self, voorkeursnaam):
        """Sets the voorkeursnaam of this PersoonsGegevensBasic.


        :param voorkeursnaam: The voorkeursnaam of this PersoonsGegevensBasic.  # noqa: E501
        :type: str
        """

        self._voorkeursnaam = voorkeursnaam

    @property
    def geboortedatum(self):
        """Gets the geboortedatum of this PersoonsGegevensBasic.  # noqa: E501


        :return: The geboortedatum of this PersoonsGegevensBasic.  # noqa: E501
        :rtype: DatumDelen
        """
        return self._geboortedatum

    @geboortedatum.setter
    def geboortedatum(self, geboortedatum):
        """Sets the geboortedatum of this PersoonsGegevensBasic.


        :param geboortedatum: The geboortedatum of this PersoonsGegevensBasic.  # noqa: E501
        :type: DatumDelen
        """

        self._geboortedatum = geboortedatum

    @property
    def overlijdensdatum(self):
        """Gets the overlijdensdatum of this PersoonsGegevensBasic.  # noqa: E501


        :return: The overlijdensdatum of this PersoonsGegevensBasic.  # noqa: E501
        :rtype: DatumDelen
        """
        return self._overlijdensdatum

    @overlijdensdatum.setter
    def overlijdensdatum(self, overlijdensdatum):
        """Sets the overlijdensdatum of this PersoonsGegevensBasic.


        :param overlijdensdatum: The overlijdensdatum of this PersoonsGegevensBasic.  # noqa: E501
        :type: DatumDelen
        """

        self._overlijdensdatum = overlijdensdatum

    @property
    def geslacht(self):
        """Gets the geslacht of this PersoonsGegevensBasic.  # noqa: E501


        :return: The geslacht of this PersoonsGegevensBasic.  # noqa: E501
        :rtype: str
        """
        return self._geslacht

    @geslacht.setter
    def geslacht(self, geslacht):
        """Sets the geslacht of this PersoonsGegevensBasic.


        :param geslacht: The geslacht of this PersoonsGegevensBasic.  # noqa: E501
        :type: str
        """

        self._geslacht = geslacht

    @property
    def partner_naam(self):
        """Gets the partner_naam of this PersoonsGegevensBasic.  # noqa: E501


        :return: The partner_naam of this PersoonsGegevensBasic.  # noqa: E501
        :rtype: str
        """
        return self._partner_naam

    @partner_naam.setter
    def partner_naam(self, partner_naam):
        """Sets the partner_naam of this PersoonsGegevensBasic.


        :param partner_naam: The partner_naam of this PersoonsGegevensBasic.  # noqa: E501
        :type: str
        """

        self._partner_naam = partner_naam

    @property
    def partner_voorvoegsels(self):
        """Gets the partner_voorvoegsels of this PersoonsGegevensBasic.  # noqa: E501


        :return: The partner_voorvoegsels of this PersoonsGegevensBasic.  # noqa: E501
        :rtype: str
        """
        return self._partner_voorvoegsels

    @partner_voorvoegsels.setter
    def partner_voorvoegsels(self, partner_voorvoegsels):
        """Sets the partner_voorvoegsels of this PersoonsGegevensBasic.


        :param partner_voorvoegsels: The partner_voorvoegsels of this PersoonsGegevensBasic.  # noqa: E501
        :type: str
        """

        self._partner_voorvoegsels = partner_voorvoegsels

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PersoonsGegevensBasic):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PersoonsGegevensBasic):
            return True

        return self.to_dict() != other.to_dict()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['frontoffice', 'frontoffice.api', 'frontoffice.models']

package_data = \
{'': ['*']}

install_requires = \
['certifi>=2020.4.5,<2021.0.0',
 'python-dateutil>=2.8.1,<3.0.0',
 'six>=1.15.0,<2.0.0',
 'urllib3>=1.25.9,<2.0.0']

setup_kwargs = {
    'name': 'pi-team-frontoffice-client',
    'version': '1.0.4',
    'description': 'A client library for FrontOffice',
    'long_description': None,
    'author': 'David Diks',
    'author_email': 'david.diks@mn.nl',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
